.. _index:

Documentation for *backtracks*
==============================

*backtracks* is a tool to fit relative astrometry with background star motion tracks

.. toctree::
   :maxdepth: 2

   installation
   tutorial.ipynb
   additional-examples.ipynb
   modules
   about
